@@ -22,8 +22,8 @@
 
 DateNavigatorContainer::DateNavigatorContainer(QWidget *parent)
     : QFrame(parent)
+    , mNavigatorView(new KDateNavigator(this))
 {
-    mNavigatorView = new KDateNavigator(this);
     mNavigatorView->setWhatsThis(
         i18n("<qt><p>Select the dates you want to "
              "display in KOrganizer's main view here. Hold the "
@@ -309,7 +309,8 @@ void DateNavigatorContainer::goPrevMonth()
 
 QPair<QDate, QDate> DateNavigatorContainer::dateLimits(int offset) const
 {
-    QDate firstMonth, lastMonth;
+    QDate firstMonth;
+    QDate lastMonth;
     if (mExtraViews.isEmpty()) {
         lastMonth = mNavigatorView->month();
     } else {
