@@ -10,6 +10,7 @@
 
 #include "filtereditdialog.h"
 #include "korganizer_debug.h"
+#include <KStatefulBrush>
 
 #include <KCalendarCore/CalFilter>
 
@@ -96,9 +97,7 @@ FilterEdit::FilterEdit(QList<KCalendarCore::CalFilter *> *filters, QWidget *pare
     connect(mCompletedCheck, &QCheckBox::toggled, mCompletedTimeSpan, &QSpinBox::setEnabled);
 }
 
-FilterEdit::~FilterEdit()
-{
-}
+FilterEdit::~FilterEdit() = default;
 
 void FilterEdit::updateFilterList()
 {
