@@ -8,6 +8,7 @@
 */
 
 #pragma once
+#include "kcmutils_version.h"
 #include "kprefsdialog.h"
 namespace Ui
 {
@@ -18,7 +19,11 @@ class KOPrefsDialogGroupwareScheduling : public Korganizer::KPrefsModule
 {
     Q_OBJECT
 public:
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     explicit KOPrefsDialogGroupwareScheduling(QWidget *parent, const QVariantList &args = {});
+#else
+    explicit KOPrefsDialogGroupwareScheduling(QObject *parent, const KPluginMetaData &data, const QVariantList &args = {});
+#endif
     ~KOPrefsDialogGroupwareScheduling() override;
 
 protected:
