@@ -8,14 +8,18 @@
 */
 
 #pragma once
-
+#include "kcmutils_version.h"
 #include "kprefsdialog.h"
 
 class KOPrefsDialogMain : public Korganizer::KPrefsModule
 {
     Q_OBJECT
 public:
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     explicit KOPrefsDialogMain(QWidget *parent, const QVariantList &args = {});
+#else
+    explicit KOPrefsDialogMain(QObject *parent, const KPluginMetaData &data, const QVariantList &args = {});
+#endif
 
 protected:
     void usrWriteConfig() override;
