@@ -8,7 +8,7 @@
 */
 
 #pragma once
-
+#include "kcmutils_version.h"
 #include "kprefsdialog.h"
 #include <QSet>
 class QTreeWidget;
@@ -21,7 +21,11 @@ class KOPrefsDialogPlugins : public Korganizer::KPrefsModule
 {
     Q_OBJECT
 public:
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     explicit KOPrefsDialogPlugins(QWidget *parent, const QVariantList &args = {});
+#else
+    explicit KOPrefsDialogPlugins(QObject *parent, const KPluginMetaData &data, const QVariantList &args = {});
+#endif
     ~KOPrefsDialogPlugins() override;
 
 protected Q_SLOTS:
