@@ -33,6 +33,7 @@
 #include <QRadioButton>
 #include <QSpinBox>
 #include <QTimeEdit>
+#include <qwidget.h>
 
 using namespace Korganizer;
 
@@ -84,6 +85,17 @@ QList<QWidget *> KPrefsWid::widgets() const
 
 KPrefsWidBool::KPrefsWidBool(KConfigSkeleton::ItemBool *item, QWidget *parent)
     : mItem(item)
+{
+    init(parent);
+}
+
+KPrefsWidBool::KPrefsWidBool(KConfigCompilerSignallingItem *item, QWidget *parent)
+    : mItem(item)
+{
+    init(parent);
+}
+
+void KPrefsWidBool::init(QWidget *parent)
 {
     mCheck = new QCheckBox(mItem->label(), parent);
     connect(mCheck, &QCheckBox::clicked, this, &KPrefsWidBool::changed);
@@ -99,12 +111,12 @@ KPrefsWidBool::KPrefsWidBool(KConfigSkeleton::ItemBool *item, QWidget *parent)
 
 void KPrefsWidBool::readConfig()
 {
-    mCheck->setChecked(mItem->value());
+    mCheck->setChecked(mItem->property().toBool());
 }
 
 void KPrefsWidBool::writeConfig()
 {
-    mItem->setValue(mCheck->isChecked());
+    mItem->setProperty(QVariant::fromValue(mCheck->isChecked()));
 }
 
 QCheckBox *KPrefsWidBool::checkBox()
@@ -615,6 +627,13 @@ void KPrefsWidManager::addWid(KPrefsWid *wid)
     mPrefsWids.append(wid);
 }
 
+KPrefsWidBool *KPrefsWidManager::addWidBool(KConfigCompilerSignallingItem *item, QWidget *parent)
+{
+    auto w = new KPrefsWidBool(item, parent);
+    addWid(w);
+    return w;
+}
+
 KPrefsWidBool *KPrefsWidManager::addWidBool(KConfigSkeleton::ItemBool *item, QWidget *parent)
 {
     auto w = new KPrefsWidBool(item, parent);
@@ -854,11 +873,20 @@ void KPrefsDialog::slotDefault()
     }
 }
 
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
 KPrefsModule::KPrefsModule(KConfigSkeleton *prefs, QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
+#else
+KPrefsModule::KPrefsModule(KConfigSkeleton *prefs, QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : KCModule(parent, data, args)
+#endif
     , KPrefsWidManager(prefs)
 {
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     Q_EMIT changed(false);
+#else
+    setNeedsSave(false);
+#endif
 }
 
 void KPrefsModule::addWid(KPrefsWid *wid)
@@ -869,15 +897,22 @@ void KPrefsModule::addWid(KPrefsWid *wid)
 
 void KPrefsModule::slotWidChanged()
 {
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     Q_EMIT changed(true);
+#else
+    setNeedsSave(true);
+#endif
 }
 
 void KPrefsModule::load()
 {
     readWidConfig();
     usrReadConfig();
-
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     Q_EMIT changed(false);
+#else
+    setNeedsSave(false);
+#endif
 }
 
 void KPrefsModule::save()
@@ -889,6 +924,9 @@ void KPrefsModule::save()
 void KPrefsModule::defaults()
 {
     setWidDefaults();
-
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     Q_EMIT changed(true);
+#else
+    setNeedsSave(true);
+#endif
 }
