@@ -9,7 +9,7 @@
 */
 
 #pragma once
-
+#include "kcmutils_version.h"
 #include <KCModule>
 #include <KConfigSkeleton>
 #include <KFile>
@@ -87,6 +87,14 @@ public:
     */
     explicit KPrefsWidBool(KConfigSkeleton::ItemBool *item, QWidget *parent = nullptr);
 
+    /**
+      Create a bool value control element consisting of a QCheckbox.
+
+      @param item    The KConfigCompilerSignallingItem representing the preferences entry.
+      @param parent  Parent widget.
+    */
+    explicit KPrefsWidBool(KConfigCompilerSignallingItem *item, QWidget *parent = nullptr);
+
     /**
       Return the QCheckbox used by this control element.
     */
@@ -98,7 +106,8 @@ public:
     QList<QWidget *> widgets() const override;
 
 private:
-    KConfigSkeleton::ItemBool *mItem = nullptr;
+    void init(QWidget *parent);
+    KConfigSkeletonItem *mItem = nullptr;
 
     QCheckBox *mCheck = nullptr;
 };
@@ -581,6 +590,14 @@ public:
     */
     virtual void addWid(KPrefsWid *);
 
+    /**
+      Register a @ref KPrefsWidBool object.
+
+      @param item    The KConfigCompilerSignallingItem representing the preferences entry.
+      @param parent  Parent widget.
+    */
+    KPrefsWidBool *addWidBool(KConfigCompilerSignallingItem *item, QWidget *parent = nullptr);
+
     /**
       Register a @ref KPrefsWidBool object.
 
@@ -772,7 +789,11 @@ class KPrefsModule : public KCModule, public KPrefsWidManager
 {
     Q_OBJECT
 public:
-    KPrefsModule(KConfigSkeleton *, QWidget *parent = nullptr, const QVariantList &args = QVariantList());
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
+    explicit KPrefsModule(KConfigSkeleton *, QWidget *parent = nullptr, const QVariantList &args = QVariantList());
+#else
+    explicit KPrefsModule(KConfigSkeleton *, QObject *parent, const KPluginMetaData &data, const QVariantList &args = QVariantList());
+#endif
 
     void addWid(KPrefsWid *) override;
 
